@@ -1,11 +1,11 @@
 """pwclip packaging information"""
 name = 'pwclip'
 provides = ['pwcli', 'pwclip', 'ykclip']
-version = '1.3.7'
+version = '1.7.8'
 install_requires = [
-    'argcomplete', 'paramiko', 'psutil', 'python-gnupg', 'PyYAML']
-url = 'https://pypi.org/project/pwclip/'
-download_url = 'http://deb.janeiskla.de/python/python3-pwclip_current_all.deb'
+    'argcomplete', 'psutil', 'PyYAML', 'pywin32 >= 1.0;platform_system=="Windows"']
+url = 'https://github.com/d0n/pwclip'
+download_url = 'http://deb.janeiskla.de/ubuntu/pool/main/p/pwclip/python3-pwclip_%s-1_all.deb'%version
 license = "GPLv3+"
 author = 'Leon Pelzer'
 description = 'password-manager - temporarily saves passwords to the clipboard'
@@ -30,26 +30,11 @@ classifiers = ['Environment :: Console',
 include_package_data = True
 long_description = ''
 try:
-	long_description = str('\n\n\n'.join(
-        str(open('pwclip/docs/changelog.rst', 'r').read()).split('\n\n\n')[:4]
-        )).format(CurrentVersion='%s (current)\n----------%s'%(
-            version, '-'*len(version)))
-except FileNotFoundError:
-	long_description = ''
-try:
-	long_description = str(
-        open('pwclip/docs/readme.rst', 'r').read()
-        ).format(ChangeLog=long_description)
-except FileNotFoundError:
-	long_description = ''
-if long_description:
-	open('%s_readme'%name, 'w+').write(long_description)
-try:
-	open('pwclip/docs/conf.py', 'w+').write(str(
-            open('pwclip/docs/conf.py.tmpl', 'r').read()
-        ).format(VersionString=version))
+	with open('docs/description.rst', 'r') as rfh:
+		long_description = rfh.read()
 except FileNotFoundError:
 	pass
+
 entry_points = {
     'console_scripts': ['pwcli = pwclip.__init__:pwcli'],
     'gui_scripts': ['pwclip = pwclip.__init__:pwclip',
@@ -58,7 +43,7 @@ package_data = {
     '': ['pwclip/docs/'],
     '': ['pwclip/example']}
 data_files=[
-    ('share/man/man1', ['pwclip/docs/_build/man/pwclip.1']),
+    ('share/man/man1', ['pwclip/docs/pwclip.1']),
     ('share/pwclip', [
         'pwclip/example/ca.crt', 'pwclip/example/commands.rst',
         'pwclip/example/ssl.crt', 'pwclip/example/ssl.key',
