@@ -1,21 +1,30 @@
 """randomisation functions"""
 from re import search
-from os import getrandom
+try:
+	from os import urandom as getrandom
+except ImportError:
+	from random import random as urandom
+	def getrandom(): return urandom()
 
 def random(limit=10, regex=r'[\w -~]'):
 	"""random character by limit"""
 	rets = []
 	while True:
 		try:
-			out = getrandom(1).decode()
-		except UnicodeDecodeError:
+			out = getrandom(1)
+		except UnicodeDecodeError as err:
+			continue
+		try:
+			out = out.decode('utf-8')
+		except (AttributeError, UnicodeDecodeError) as err:
+			#print(err)
 			continue
 		try:
 			if search(regex, out).group(0):
 				rets.append(out.strip())
 		except AttributeError:
 			continue
-		if len(rets) >= int(limit):
+		if len(''.join(rets)) >= int(limit):
 			break
 	return ''.join(r for r in rets)
 
