@@ -19,8 +19,8 @@ try:
 	import gi
 	gi.require_version('Notify', '0.7')
 	from gi.repository import Notify as xnote
-except (AttributeError, ImportError) as err:
-	def xnotify(*_): """xnotify faker function""" ;return
+except (AttributeError, ImportError, ValueError) as err:
+	def xnotify(msg, **_): """xnotify faker function""" ;return
 else:
 	def xnotify(msg, name=stack()[1][3], wait=5):
 		"""
@@ -29,7 +29,7 @@ else:
 		try:
 			xnote.init(str(name))
 			note = xnote.Notification.new(msg)
-			note.set_timeout(int(int(wait*1000)))
+			note.set_timeout(int(wait*1000))
 			note.show()
 		except (NameError, RuntimeError):
 			pass
